@@ -14,8 +14,12 @@ around 'find_user' => sub {
   my ( $authinfo, $c ) = @_;
   my $user = $self->$orig(@_);
   my $token = $authinfo->{token} or return;
-  $self->_apply_client_role( $user, $authinfo->{token} );
-  return $user;
+  if($user) {
+    $self->_apply_client_role( $user, $authinfo->{token} );
+    return $user;
+  } else {
+    return;
+  }
 };
 
 around 'restore_user' => sub {
@@ -75,7 +79,7 @@ CatalystX::OAuth2::ClientInjector - A role for automatically providing an oauth2
 
 =head1 VERSION
 
-version 0.001006
+version 0.001007
 
 =head1 AUTHOR
 
